@@ -1,9 +1,7 @@
 #!/bin/bash
 
-if [[ "$(python3 -m venv 2>&1)" =~ "No module named venv" ]]; then
-  echo "Virtualenv not installed. This script requires virtual env, please install it."
-  exit 1;
-fi
+# Make sure we propegate exit codes, for kokoro.
+set -e
 
 # Set up temp dir containing atheris and cd into it.
 SRC_DIR="$1"
@@ -16,7 +14,7 @@ cp -r . "${TMP_DIR?}"
 cd "${TMP_DIR?}"
 
 # Set up virtual env
-python3 -m venv .
+python3 -m virtualenv .
 source bin/activate
 python -m pip install .
 python -m pip install PyInstaller
