@@ -22,8 +22,8 @@ typedef int (*UserCallback)(const uint8_t *Data, std::size_t Size);
 int FuzzerDriver(int *argc, char ***argv, UserCallback Callback);
 }  // namespace fuzzer
 
-extern "C" __attribute__((visibility("default"))) int
-LLVMFuzzerRunDriver(int *argc, char ***argv,
-                    int (*UserCb)(const uint8_t *Data, std::size_t Size)) {
+extern "C" __attribute__((visibility("default"))) int LLVMFuzzerRunDriver(
+    int *argc, char ***argv,
+    int (*UserCb)(const uint8_t *Data, std::size_t Size)) {
   return fuzzer::FuzzerDriver(argc, argv, UserCb);
 }
