@@ -56,6 +56,11 @@ def never_fail(data):
       pass
 
 
+@atheris.instrument_func
+def raise_with_surrogates(data):
+  raise RuntimeError("abc \ud927 def")
+
+
 @atheris.instrument_func
 def bytes_comparison(data):
   if data == b"foobarbazbiz":
@@ -184,6 +189,12 @@ class IntegrationTests(unittest.TestCase):
         args=["-atheris_runs=2"],
         expected_output=b"Exiting gracefully.")
 
+  def testExceptionWithSurrogates(self):
+    fuzz_test_lib.run_fuzztest(
+        raise_with_surrogates,
+        args=["-atheris_runs=1"],
+        expected_output=b"abc \\ud927 def")
+
   def testRunsOutCount(self):
     fuzz_test_lib.run_fuzztest(
         never_fail, args=["-atheris_runs=3"], expected_output=b"Done 3 in ")
