@@ -14,8 +14,8 @@
  * limitations under the License.
  */
 
-#ifndef THIRD_PARTY_PY_ATHERIS_MACROS_H_
-#define THIRD_PARTY_PY_ATHERIS_MACROS_H_
+#ifndef ATHERIS_MACROS_H_
+#define ATHERIS_MACROS_H_
 
 #define NO_SANITIZE_ADDRESS __attribute__((no_sanitize_address))
 
@@ -33,6 +33,10 @@
 #define sighandler_t sig_t
 #endif  // __APPLE__
 
+#if !defined(MAP_ANONYMOUS) && defined(MAP_ANON)
+#define MAP_ANONYMOUS MAP_ANON
+#endif
+
 #define NO_SANITIZE NO_SANITIZE_ADDRESS NO_SANITIZE_MEMORY
 
-#endif  // THIRD_PARTY_PY_ATHERIS_MACROS_H_
+#endif  // ATHERIS_MACROS_H_
